@@ -1,6 +1,6 @@
 """Init."""
 
-from . import logging_tools
+from . import argparse_tools, logging_tools
 from .enviro_tools import from_environment, from_environment_as_dataclass  # noqa
 from .setup_tools import SetupShop  # noqa
 from .strtobool import strtobool
@@ -11,10 +11,11 @@ __all__ = [
     "SetupShop",
     "logging_tools",
     "strtobool",
+    "argparse_tools",
 ]
 
 # version is a human-readable version number.
-__version__ = "1.4.0"
+__version__ = "1.5.0"
 
 # version_info is a four-tuple for programmatic comparison. The first
 # three numbers are the components of the version number. The fourth
